@@ -16,6 +16,10 @@ class CookiecutterFeature(Feature):
     def name(self) -> str:
         return "cookiecutter"
 
+    @property
+    def dependencies(self) -> Iterable[str]:
+        return ["core"]
+
     @property
     def schema(self) -> ClassVar[CookiecutterFeatureSchema]:
         return CookiecutterFeatureSchema
